@@ -193,7 +193,7 @@ class predictor(object):
             weights[m//skip] = current
         self.weightsTrain = np.array(weights)
    
-    def reweight(self, trainX, trainY, architecture, skip=10, likelihood=None):
+    def reweight(self, architecture, trainX=None, trainY=None, skip=1, likelihood=None):
         """ Calculate new weights for each network if they have the new 
         hyper paramters described in architecture. The weights are calculated
         according to p(theta|priors2)/p(theta|priors1). The new priors can be
@@ -264,7 +264,7 @@ class predictor(object):
         
         """
         predictions = self.predict(inputData, skip=1)
-        output = np.array(predictions).T
+        output = np.squeeze(np.array(predictions)).T
         
         valFunc=0
         accepted=0
@@ -281,7 +281,7 @@ class predictor(object):
         
     def integratedAutoCorrelationTime(self, inputData):
         predictions = self.predict(inputData, skip=1)
-        output = np.array(predictions).T
+        output = np.squeeze(np.array(predictions)).T
         
         val=0
         accepted=0
